@@ -38,7 +38,7 @@ class Page:
 
     def create(self, website, section):
         execute('SADD', Dimension.PAGE.value, f'{self.id}:{self.url}')
-        # log(f'SADD {Dimension.SECTION.value} {self.id}:{self.pretty_name}')
+        # log(f'SADD {Dimension.SECTION.value} {self.id}:{self.name}')
         execute('JSON.SET', self.dimension_key, '.', json.dumps({
             'id': self.id,
             'url': self.url,
@@ -48,7 +48,7 @@ class Page:
             },
             'section': {
                 'id': section.id,
-                'pretty_name': section.pretty_name,
+                'name': section.name,
                 'levels': section.levels
             },
             'article_id': self.article_id,
@@ -86,8 +86,8 @@ class Page:
 
     def expire_metrics(self):
         # Todo: put expire in method params
-        execute('EXPIRE', self.metric_pageviews_key, 720)
-        execute('EXPIRE', self.metric_unique_device_key, 720)
+        execute('EXPIRE', self.metric_pageviews_key, 3600)
+        execute('EXPIRE', self.metric_unique_device_key, 3600)
 
     def is_exists(self):
         x = execute('EXISTS', self.dimension_key)
@@ -109,15 +109,20 @@ class Page:
     def write_metadata(self, stream_names):
         parsed_key = parse_key_name(self.dimension_ts_key)
 
-        execute('XADD', stream_names.get('page_pageviews'), '*',
+        execute('XADD', stream_names.get('page_pageviews'), 'MAXLEN', '86400000', '*',
                 'dimension', Dimension.PAGE.value,
                 'id', self.id,
-                'ts', parsed_key.get('ts'))
+                'ts', parsed_key.get('ts'),
+                'merged_key', self.metric_pageviews_key)
         # tracker_log(f'XADD {stream_names.get("page_pageviews")} * dimension {Dimension.PAGE.value} id {self.id} ts {parsed_key.get("ts")}')
-        execute('XADD', stream_names.get('page_unique_devices'), '*',
+        execute('XADD', stream_names.get('page_unique_devices'), 'MAXLEN', '86400000', '*',
                 'dimension', Dimension.PAGE.value,
                 'id', self.id,
-                'ts', parsed_key.get('ts'))
+                'ts', parsed_key.get('ts'),
+                'merged_key', self.metric_unique_device_key)
+
+    def send_to_enrich(self):
+        execute('XADD', 'ST:ENRICH:P:::', 'MAXLEN', '86400000', '*', 'key', self.dimension_key, 'article_id', self.article_id)
 
 
 def load_page(website, section, page, device, output_stream_names):
@@ -125,14 +130,15 @@ def load_page(website, section, page, device, output_stream_names):
         page.create(website, section)
         page.create_metrics()
         page.incr_metrics(device.id)
-        # page.expire_metrics()
+        page.expire_metrics()
         page.update_last_visited()
         page.write_metadata(stream_names=output_stream_names)
+        page.send_to_enrich()
     else:
         if page.has_metrics() < 2:
             page.create_metrics()
             page.incr_metrics(device.id)
-            # page.expire_metrics()
+            page.expire_metrics()
             page.update_last_visited()
             page.write_metadata(stream_names=output_stream_names)
         else:
