@@ -42,6 +42,14 @@ def transform(records, number_of_rotated_keys):
             })
         else:
             [results.get('reinject').append({
+                'key': create_key_name(
+                    Type.CMS.value,
+                    '',
+                    row[0],
+                    '',
+                    row[1],
+                    Metric.PAGEVIEWS.value
+                ),
                 'dimension': row[0],
                 'ts': row[1]
             }) for row in zip(df_sliced['dimension'], df_sliced['ts'])]
@@ -60,16 +68,32 @@ def load(job_name, records, dimension, write_to_ts, timeseries_name, key_expire_
         else:
             return ts
 
+    capped_stream = get_maxlen_capped_stream(timeseries_name, dimension)
+
+    # tracker_log(f'PG - MAXLEN {type(capped_stream)} {capped_stream}')
+
     for cms_reinject in records.get('reinject'):
         for id in records.get('id'):
-            execute('XADD', reinject_stream_name, '*', 'id', id, 'dimension', cms_reinject.get('dimension'), 'ts',
-                    cms_reinject.get('ts'))
+            execute('XADD', reinject_stream_name, 'MAXLEN', f'{capped_stream}', '*',
+                    'id', id,
+                    'dimension', cms_reinject.get('dimension'),
+                    'ts', cms_reinject.get('ts'),
+                    'merged_key', cms_reinject.get('key'))
 
     for cms_merge in records.get("merge"):
         if execute('EXISTS', cms_merge.get('name')) != 1:
-            execute('CMS.INITBYDIM', cms_merge.get('name'), 2000, 5)
-            execute('CMS.MERGE', cms_merge.get('name'), len(cms_merge.get('keys')), *cms_merge.get('keys'))
-            tracker_log(f'Merge Pageviews {cms_merge.get("name")}', f'{job_name} ')
+            try:
+                execute('CMS.INITBYDIM', cms_merge.get('name'), 2000, 5)
+            except Exception as e:
+                tracker_log(f'Error during CMS key init: {e} {cms_merge.get("name")}', f'{job_name} ', 'warning')
+
+            try:
+                execute('CMS.MERGE', cms_merge.get('name'), len(cms_merge.get('keys')), *cms_merge.get('keys'))
+            except Exception as e:
+                tracker_log(f'Error during CMS merging key: {e} {cms_merge.get("name")} {len(cms_merge.get("keys"))} {cms_merge.get("keys")}', f'{job_name} ', 'warning')
+                # FixMe: one of merged keys is expire or missing, create strategy to not crash app and standardize data
+
+            # tracker_log(f'Merge Pageviews {cms_merge.get("name")}', f'{job_name} ')
 
             parsed_key_name = parse_key_name(cms_merge.get('name'))
 
@@ -91,36 +115,43 @@ def load(job_name, records, dimension, write_to_ts, timeseries_name, key_expire_
                         metric=Metric.PAGEVIEWS.value)
 
                     if dimension == Dimension.WEBSITE.value:
-                        record_infos = execute('FT.SEARCH', index_name, f'@id:{{{id}}}', 'RETURN', '1', 'name')
+                        record_infos = execute('FT.SEARCH', index_name, f'@id:{{{id}}}', 'RETURN', '3',
+                                               'name', 'AS', 'website_name')
                         # tracker_log(f'Get {dimension} infos - {record_infos}', f'{job_name} ')
                         execute('TS.ADD', timeseries_key_name, get_ts(parsed_key_name.get('ts')), pageviews,
                                 'ON_DUPLICATE', 'LAST',
-                                'LABELS', 'dimension', dimension, Dimension.METRIC.value, Metric.PAGEVIEWS.value,
+                                'LABELS', 'ts_name', timeseries_name,
+                                'dimension', dimension, Dimension.METRIC.value, Metric.PAGEVIEWS.value,
                                 'website_id', id, *record_infos[-1])
-                        tracker_log(f'Write to Timeseries {id}->{timeseries_key_name}', f'{job_name} ')
+                        # tracker_log(f'Write {pageviews} pageviews to {timeseries_key_name} at {get_ts(parsed_key_name.get("ts"))}', f'{job_name} - ')
                     elif dimension == Dimension.SECTION.value:
-                        record_infos = execute('FT.SEARCH', index_name, f'@id:{{{id}}}', 'RETURN', '3',
-                                               'pretty_name', 'website_id', 'website_name')
+                        record_infos = execute('FT.SEARCH', index_name, f'@id:{{{id}}}', 'RETURN', '5',
+                                               'name', 'AS', 'section_name', 'website_id', 'website_name')
                         # tracker_log(f'Get {dimension} infos - {record_infos}', f'{job_name} ')
                         execute('TS.ADD', timeseries_key_name, get_ts(parsed_key_name.get("ts")), pageviews,
                                 'ON_DUPLICATE', 'LAST',
-                                'LABELS', 'dimension', dimension, Dimension.METRIC.value, Metric.PAGEVIEWS.value,
+                                'LABELS', 'ts_name', timeseries_name,
+                                'dimension', dimension, Dimension.METRIC.value, Metric.PAGEVIEWS.value,
                                 'section_id', id, *record_infos[-1])
-                        tracker_log(f'Write to Timeseries {id}->{timeseries_key_name}', f'{job_name} ')
+                        # tracker_log(f'Write to Timeseries {id}->{timeseries_key_name}', f'{job_name} ')
                     elif dimension == Dimension.PAGE.value:
                         record_infos = execute('FT.SEARCH', index_name, f'@id:{{{id}}}', 'RETURN', '5',
-                                               'website_id', 'website_name', 'section_id',
-                                               'section_pretty_name', 'article_id')
+                                               'website_id', 'website_name', 'section_id', 'section_name', 'article_id')
                         # tracker_log(f'Get {dimension} infos - {record_infos}', f'{job_name} ')
                         execute('TS.ADD', timeseries_key_name, get_ts(parsed_key_name.get("ts")), pageviews,
                                 'ON_DUPLICATE', 'LAST',
-                                'LABELS', 'dimension', dimension, Dimension.METRIC.value, Metric.PAGEVIEWS.value,
+                                'LABELS', 'ts_name', timeseries_name,
+                                'dimension', dimension, Dimension.METRIC.value, Metric.PAGEVIEWS.value,
                                 'page_id', id, *record_infos[-1])
-                        tracker_log(f'Write to Timeseries {id}->{timeseries_key_name}', f'{job_name} ')
+                        # tracker_log(f'Write to Timeseries {id}->{timeseries_key_name}', f'{job_name} ')
 
             for id in records.get('id'):
-                execute('XADD', output_stream_name, '*', 'dimension', dimension, 'id', id, 'ts',
-                        parsed_key_name.get('ts'))
-                tracker_log(f'Write to OutputStream {id}->{output_stream_name}', f'{job_name} ')
+                execute('XADD', output_stream_name, 'MAXLEN', f'{capped_stream}', '*',
+                        'dimension', dimension,
+                        'id', id,
+                        'ts', parsed_key_name.get('ts'),
+                        'merged_key', cms_merge.get('name'))
 
-            # execute('EXPIRE', cms_merge.get('name'), key_expire_duration_sc)
+                # tracker_log(f'Write to OutputStream {id}->{output_stream_name}', f'{job_name} ')
+
+            execute('EXPIRE', cms_merge.get('name'), key_expire_duration_sc)
